@@ -3,7 +3,6 @@
 /**
  * holds the PMA_List_Database class
  *
- * @version $Id$
  * @package phpMyAdmin
  */
 
@@ -295,7 +294,7 @@ require_once './libraries/List.class.php';
         }
 
         foreach ($this->getLimitedItems($offset, $count) as $key => $db) {
-            // garvin: Get comments from PMA comments table
+            // Get comments from PMA comments table
             $db_tooltip = '';
 
             if (isset($db_tooltips[$db])) {
@@ -309,7 +308,7 @@ require_once './libraries/List.class.php';
                 // have the db name, the separator, then the rest which
                 // might contain a separator
                 // like dbname_the_rest
-                $pos = strpos($db, $separator);
+                $pos = strpos($db, $separator, 1);
 
                 if ($pos !== false) {
                     break;
@@ -372,7 +371,7 @@ require_once './libraries/List.class.php';
         $return = '<ul id="databaseList" xml:lang="en" dir="ltr">' . "\n";
         foreach ($this->getGroupedDetails($offset, $count) as $group => $dbs) {
             if (count($dbs) > 1) {
-                $return .= '<li>' . htmlspecialchars($group) . '<ul>' . "\n";
+                $return .= '<li class="group"><span>' . htmlspecialchars($group) . '</span><ul>' . "\n";
                 // whether display db_name cut by the group part
                 $cut = true;
             } else {
@@ -428,7 +427,7 @@ require_once './libraries/List.class.php';
         $return = '<select name="db" id="lightm_db" xml:lang="en" dir="ltr"'
             . ' onchange="if (this.value != \'\') window.parent.openDb(this.value);">' . "\n"
             . '<option value="" dir="' . $GLOBALS['text_dir'] . '">'
-            . '(' . $GLOBALS['strDatabases'] . ') ...</option>' . "\n";
+            . '(' . __('Databases') . ') ...</option>' . "\n";
         foreach ($this->getGroupedDetails($offset, $count) as $group => $dbs) {
             if (count($dbs) > 1) {
                 $return .= '<optgroup label="' . htmlspecialchars($group)
@@ -468,7 +467,7 @@ require_once './libraries/List.class.php';
     protected function _checkAgainstPrivTables()
     {
         // 1. get allowed dbs from the "mysql.db" table
-        // lem9: User can be blank (anonymous user)
+        // User can be blank (anonymous user)
         $local_query = "
             SELECT DISTINCT `Db` FROM `mysql`.`db`
             WHERE `Select_priv` = 'Y'
@@ -488,7 +487,7 @@ require_once './libraries/List.class.php';
             // now populated with actual database names instead of
             // with regular expressions.
             $tmp_alldbs = PMA_DBI_query('SHOW DATABASES;', $GLOBALS['controllink']);
-            // loic1: all databases cases - part 2
+            // all databases cases - part 2
             if (isset($tmp_mydbs['%'])) {
                 while ($tmp_row = PMA_DBI_fetch_row($tmp_alldbs)) {
                     $dblist[] = $tmp_row[0];
@@ -501,7 +500,7 @@ require_once './libraries/List.class.php';
                         $tmp_mydbs[$tmp_db] = 0;
                     } elseif (!isset($dblist[$tmp_db])) {
                         foreach ($tmp_mydbs as $tmp_matchpattern => $tmp_value) {
-                            // loic1: fixed bad regexp
+                            // fixed bad regexp
                             // TODO: db names may contain characters
                             //       that are regexp instructions
                             $re        = '(^|(\\\\\\\\)+|[^\])';
