@@ -5,7 +5,6 @@
  *
  * usally called as form action from tbl_change.php to insert or update table rows
  *
- * @version $Id$
  *
  * @todo 'edit_next' tends to not work as expected if used ... at least there is no order by
  *       it needs the original query and the row number and than replace the LIMIT clause
@@ -54,7 +53,7 @@ if (! defined('PMA_NO_VARIABLES_IMPORT')) {
  * Gets some core libraries
  */
 require_once './libraries/common.inc.php';
-$blob_streaming_active = $_SESSION['PMA_Config']->get('BLOBSTREAMING_PLUGINS_EXIST');
+$blob_streaming_active = $GLOBALS['PMA_Config']->get('BLOBSTREAMING_PLUGINS_EXIST');
 
 // Check parameters
 PMA_checkParameters(array('db', 'table', 'goto'));
@@ -66,6 +65,9 @@ PMA_DBI_select_db($GLOBALS['db']);
  */
 $goto_include = false;
 
+// Needed for generation of Inline Edit anchors
+$GLOBALS['js_include'][] = 'sql.js';
+
 if (isset($_REQUEST['insert_rows']) && is_numeric($_REQUEST['insert_rows']) && $_REQUEST['insert_rows'] != $cfg['InsertRows']) {
     $cfg['InsertRows'] = $_REQUEST['insert_rows'];
     $GLOBALS['js_include'][] = 'tbl_change.js';
@@ -96,7 +98,7 @@ if (isset($_REQUEST['after_insert'])
                 // must find a unique condition based on unique key,
                 // not a combination of all fields
                 list($unique_condition, $clause_is_unique) = PMA_getUniqueCondition($res, count($meta), $meta, $row, true);
-                if (! empty($unique_condition)) { 
+                if (! empty($unique_condition)) {
                     $_SESSION['edit_next'] = $unique_condition;
                 }
                 unset($unique_condition, $clause_is_unique);
@@ -138,7 +140,8 @@ if (isset($_REQUEST['where_clause'])) {
     // we were editing something => use the WHERE clause
     $loop_array = (is_array($_REQUEST['where_clause']) ? $_REQUEST['where_clause'] : array($_REQUEST['where_clause']));
     $using_key  = true;
-    $is_insert  = ($_REQUEST['submit_type'] == $GLOBALS['strInsertAsNewRow']);
+    $is_insert  = ($_REQUEST['submit_type'] == 'insert') || ($_REQUEST['submit_type'] == 'showinsert') || ($_REQUEST['submit_type'] == 'insertignore');
+    $is_insertignore  = ($_REQUEST['submit_type'] == 'insertignore');
 } else {
     // new row => use indexes
     $loop_array = array();
@@ -147,6 +150,7 @@ if (isset($_REQUEST['where_clause'])) {
     }
     $using_key  = false;
     $is_insert  = true;
+    $is_insertignore = false;
 }
 
 $query = array();
@@ -166,7 +170,7 @@ $func_no_param = array(
     'CURRENT_USER',
 );
 
-foreach ($loop_array as $rowcount => $where_clause) {
+foreach ($loop_array as $rownumber => $where_clause) {
     // skip fields to be ignored
     if (! $using_key && isset($_REQUEST['insert_ignore_' . $where_clause])) {
         continue;
@@ -177,42 +181,38 @@ foreach ($loop_array as $rowcount => $where_clause) {
 
     // Map multi-edit keys to single-level arrays, dependent on how we got the fields
     $me_fields =
-        isset($_REQUEST['fields']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields']['multi_edit'][$rownumber]
         : array();
     $me_fields_name =
-        isset($_REQUEST['fields_name']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_name']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_name']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_name']['multi_edit'][$rownumber]
         : null;
     $me_fields_prev =
-        isset($_REQUEST['fields_prev']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_prev']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_prev']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_prev']['multi_edit'][$rownumber]
         : null;
     $me_funcs =
-        isset($_REQUEST['funcs']['multi_edit'][$rowcount])
-        ? $_REQUEST['funcs']['multi_edit'][$rowcount]
+        isset($_REQUEST['funcs']['multi_edit'][$rownumber])
+        ? $_REQUEST['funcs']['multi_edit'][$rownumber]
         : null;
     $me_fields_type =
-        isset($_REQUEST['fields_type']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_type']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_type']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_type']['multi_edit'][$rownumber]
         : null;
     $me_fields_null =
-        isset($_REQUEST['fields_null']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_null']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_null']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_null']['multi_edit'][$rownumber]
         : null;
     $me_fields_null_prev =
-        isset($_REQUEST['fields_null_prev']['multi_edit'][$rowcount])
-        ? $_REQUEST['fields_null_prev']['multi_edit'][$rowcount]
+        isset($_REQUEST['fields_null_prev']['multi_edit'][$rownumber])
+        ? $_REQUEST['fields_null_prev']['multi_edit'][$rownumber]
         : null;
     $me_auto_increment =
-        isset($_REQUEST['auto_increment']['multi_edit'][$rowcount])
-        ? $_REQUEST['auto_increment']['multi_edit'][$rowcount]
+        isset($_REQUEST['auto_increment']['multi_edit'][$rownumber])
+        ? $_REQUEST['auto_increment']['multi_edit'][$rownumber]
         : null;
 
-    if ($blob_streaming_active) {
-        $primary_field = PMA_BS_GetPrimaryField($GLOBALS['db'], $GLOBALS['table']);
-    }
-
     // Fetch the current values of a row to use in case we have a protected field
     // @todo possibly move to ./libraries/tbl_replace_fields.inc.php
     if ($is_insert && $using_key && isset($me_fields_type) && is_array($me_fields_type) && isset($where_clause)) {
@@ -224,35 +224,39 @@ foreach ($loop_array as $rowcount => $where_clause) {
 
         require './libraries/tbl_replace_fields.inc.php';
 
-        // rajk - for blobstreaming
-	if ($blob_streaming_active && (NULL != $primary_field || strlen($primary_field) > 0)) {
+        // for blobstreaming
+        if ($blob_streaming_active) {
             $remove_blob_repo = isset($_REQUEST['remove_blob_repo_' . $key]) ? $_REQUEST['remove_blob_repo_' . $key] : NULL;
             $upload_blob_repo = isset($_REQUEST['upload_blob_repo_' . $key]) ? $_REQUEST['upload_blob_repo_' . $key] : NULL;
 
             // checks if an existing blob repository reference should be removed
-            if (isset($remove_blob_repo) && !isset($upload_blob_repo)) {
-		$remove_blob_reference = $_REQUEST['remove_blob_ref_' . $key];
-		if (isset($remove_blob_reference)) {
-                    $val = "''";
-		}
-
-		// checks if this field requires a bs reference attached to it
-		if (isset($upload_blob_repo)) {
-			// get the most recent BLOB reference
-                    $bs_reference = PMA_File::getRecentBLOBReference();
-
-                    // if the most recent BLOB reference exists, set it as a field value
-                    if (!is_null($bs_reference)) {
-			$val = "'" . PMA_sqlAddslashes($bs_reference) . "'";
-                    }
-		}
+            if (isset($remove_blob_repo) && ! isset($upload_blob_repo)) {
+                $remove_blob_reference = $_REQUEST['remove_blob_ref_' . $key];
+                if (isset($remove_blob_reference)) {
+                    $val = "NULL";
+                }
             }
-	}
+
+            // checks if this field requires a bs reference attached to it
+            if (isset($upload_blob_repo)) {
+                // get the most recent BLOB reference
+                $bs_reference = PMA_File::getRecentBLOBReference();
+
+                // if the most recent BLOB reference exists, set it as a field value
+                if (!is_null($bs_reference)) {
+                    $val = "'" . PMA_sqlAddslashes($bs_reference) . "'";
+                }
+            }
+        }
 
         if (empty($me_funcs[$key])) {
             $cur_value = $val;
         } elseif ('UNIX_TIMESTAMP' === $me_funcs[$key] && $val != "''") {
             $cur_value = $me_funcs[$key] . '(' . $val . ')';
+        } elseif ('UUID' === $me_funcs[$key]) {
+            /* This way user will know what UUID new row has */
+            $uuid = PMA_DBI_fetch_value('SELECT UUID()');
+            $cur_value = "'" . $uuid . "'";
         } elseif (in_array($me_funcs[$key], $func_no_param)) {
             $cur_value = $me_funcs[$key] . '()';
         } else {
@@ -310,24 +314,29 @@ unset($me_fields_name, $me_fields_prev, $me_funcs, $me_fields_type, $me_fields_n
 
 // Builds the sql query
 if ($is_insert && count($value_sets) > 0) {
-    $query[] = 'INSERT INTO ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
+    if ($is_insertignore) {
+        $insert_command = 'INSERT IGNORE ';
+    } else {
+        $insert_command = 'INSERT ';
+    }
+    $query[] = $insert_command . 'INTO ' . PMA_backquote($GLOBALS['db']) . '.' . PMA_backquote($GLOBALS['table'])
         . ' (' . implode(', ', $query_fields) . ') VALUES (' . implode('), (', $value_sets) . ')';
+    unset($insert_command);
 
-    unset($query_fields, $value_sets);
-
-    $message = PMA_Message::success('strRowsInserted');
-} elseif (! empty($query)) {
-    $message = PMA_Message::success('strRowsAffected');
-} else {
+    unset($query_fields);
+} elseif (empty($query)) {
     // No change -> move back to the calling script
-    $message = PMA_Message::success('strNoModification');
-    $GLOBALS['js_include'][] = 'functions.js';
+    //
+    // Note: logic passes here for inline edit
+    $message = PMA_Message::success(__('No change'));
     $active_page = $goto_include;
-    require_once './libraries/header.inc.php';
+    if(! $GLOBALS['is_ajax_request'] == true) {
+        require_once './libraries/header.inc.php';
+    }
     require './' . PMA_securePath($goto_include);
     exit;
 }
-unset($me_fields, $is_insert);
+unset($me_fields, $is_insertignore);
 
 /**
  * Executes the sql query and get the result, then move back to the calling
@@ -338,7 +347,7 @@ if (! empty($GLOBALS['sql_query'])) {
     $return_to_sql_query = $GLOBALS['sql_query'];
 }
 $GLOBALS['sql_query'] = implode('; ', $query) . ';';
-// to ensure that the query is displayed in case of 
+// to ensure that the query is displayed in case of
 // "insert as new row" and then "insert another new row"
 $GLOBALS['display_query'] = $GLOBALS['sql_query'];
 
@@ -348,6 +357,10 @@ $warning_messages = array();
 $error_messages = array();
 
 foreach ($query as $single_query) {
+    if ($_REQUEST['submit_type'] == 'showinsert') {
+        $last_messages[] = PMA_Message::notice(__('Showing SQL query'));
+        continue;
+    }
     if ($GLOBALS['cfg']['IgnoreMultiSubmitErrors']) {
         $result = PMA_DBI_try_query($single_query);
     } else {
@@ -355,7 +368,7 @@ foreach ($query as $single_query) {
     }
 
     if (! $result) {
-        $error_messages[] = PMA_DBI_getError();
+        $error_messages[] = PMA_Message::sanitize(PMA_DBI_getError());
     } else {
         // The next line contains a real assignment, it's not a typo
         if ($tmp = @PMA_DBI_affected_rows()) {
@@ -371,7 +384,7 @@ foreach ($query as $single_query) {
             if ($total_affected_rows > 0) {
                 $insert_id = $insert_id + $total_affected_rows - 1;
             }
-            $last_message = PMA_Message::notice('strInsertedRowId');
+            $last_message = PMA_Message::notice(__('Inserted row id: %1$d'));
             $last_message->addParam($insert_id);
             $last_messages[] = $last_message;
         }
@@ -379,24 +392,25 @@ foreach ($query as $single_query) {
     } // end if
 
     foreach (PMA_DBI_get_warnings() as $warning) {
-        $warning_messages[] = $warning['Level'] . ': #' . $warning['Code']
-            . ' ' . $warning['Message'];
+        $warning_messages[] = PMA_Message::sanitize($warning['Level'] . ': #' . $warning['Code']
+            . ' ' . $warning['Message']);
     }
 
     unset($result);
 }
 unset($single_query, $query);
 
-$message->addParam($total_affected_rows);
+if ($is_insert && count($value_sets) > 0) {
+    $message = PMA_Message::inserted_rows($total_affected_rows);
+} else {
+    $message = PMA_Message::affected_rows($total_affected_rows);
+}
+
 $message->addMessages($last_messages, '<br />');
 
 if (! empty($warning_messages)) {
-    /**
-     * @todo use a <div class="warning"> in PMA_showMessage() for this part of
-     * the message
-     */
     $message->addMessages($warning_messages, '<br />');
-    $message->isWarning(true);
+    $message->isError(true);
 }
 if (! empty($error_messages)) {
     $message->addMessages($error_messages);
@@ -404,6 +418,12 @@ if (! empty($error_messages)) {
 }
 unset($error_messages, $warning_messages, $total_affected_rows, $last_messages, $last_message);
 
+if($GLOBALS['is_ajax_request'] == true) {
+
+    $extra_data['sql_query'] = PMA_showMessage(NULL, $GLOBALS['display_query']);
+    PMA_ajaxResponse($message, $message->isSuccess(), $extra_data);
+}
+
 if (isset($return_to_sql_query)) {
     $disp_query = $GLOBALS['sql_query'];
     $disp_message = $message;
@@ -412,9 +432,8 @@ if (isset($return_to_sql_query)) {
 }
 
 $GLOBALS['js_include'][] = 'tbl_change.js';
-$GLOBALS['js_include'][] = 'functions.js';
 // in case we call sql.php which needs those:
-$GLOBALS['js_include'][] = 'mootools.js';
+$GLOBALS['js_include'][] = 'jquery/jquery-ui-1.8.custom.js';
 
 $active_page = $goto_include;
 
